@@ -786,38 +786,38 @@ avatar_chooser_drag_data_received_cb (GtkWidget          *widget,
 	gchar    *target_type;
 	gboolean  handled = FALSE;
 
-	target_type = gdk_atom_name (selection_data->target);
+	target_type = gdk_atom_name (gtk_selection_data_get_target (selection_data));
 	if (!strcmp (target_type, URI_LIST_TYPE)) {
 		GFile            *file;
 		GFileInputStream *input_stream;
 		gchar            *nl;
 		gchar            *data = NULL;
 
-		nl = strstr (selection_data->data, "\r\n");
+		nl = strstr (gtk_selection_data_get_data (selection_data), "\r\n");
 		if (nl) {
 			gchar *uri;
 
-			uri = g_strndup (selection_data->data,
-					 nl - (gchar *) selection_data->data);
+			uri = g_strndup (gtk_selection_data_get_data (selection_data),
+					 nl - (gchar *) gtk_selection_data_get_data (selection_data));
 
 			file = g_file_new_for_uri (uri);
 			g_free (uri);
 		} else {
-			file = g_file_new_for_uri (selection_data->data);
+			file = g_file_new_for_uri (gtk_selection_data_get_data (selection_data));
 		}
 
 		input_stream = g_file_read (file, NULL, NULL);
 
 		if (input_stream != NULL) {
 			GFileInfo *info;
-			
+
 			info = g_file_query_info (file,
 						  G_FILE_ATTRIBUTE_STANDARD_SIZE,
 						  0, NULL, NULL);
 			if (info != NULL) {
 				goffset size;
 				gssize bytes_read;
-				
+
 				size = g_file_info_get_size (info);
 				data = g_malloc (size);
 
@@ -838,7 +838,7 @@ avatar_chooser_drag_data_received_cb (GtkWidget          *widget,
 
 			g_object_unref (input_stream);
 		}
-		
+
 		g_object_unref (file);
 	}
 
