@@ -302,7 +302,7 @@ contact_list_view_drag_data_received (GtkWidget         *view,
 	account_id = strv[0];
 	contact_id = strv[1];
   account_manager = empathy_account_manager_dup_singleton ();
-	account = empathy_account_manager_lookup (account_manager, account_id);
+	account = empathy_account_manager_get_account (account_manager, account_id);
 	if (account) {
 		TpConnection *connection;
 
@@ -364,6 +364,7 @@ contact_list_view_drag_motion (GtkWidget      *widget,
 	gboolean               is_row;
 	gboolean               is_different = FALSE;
 	gboolean               cleanup = TRUE;
+	int                    action = 0;
 
 	is_row = gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget),
 						x,
@@ -382,6 +383,13 @@ contact_list_view_drag_motion (GtkWidget      *widget,
 		cleanup &= FALSE;
 	}
 
+	if (context->actions == GDK_ACTION_COPY) {
+		action = context->suggested_action;
+	} else if (context->actions & GDK_ACTION_MOVE) {
+		action = GDK_ACTION_MOVE;
+	}
+	gdk_drag_status (context, action, time);
+
 	if (!is_different && !cleanup) {
 		return TRUE;
 	}
