@@ -30,6 +30,8 @@
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 
+#include <telepathy-glib/interfaces.h>
+
 #include "empathy-tp-chat.h"
 #include "empathy-chatroom-manager.h"
 #include "empathy-account-manager.h"
@@ -100,7 +102,8 @@ chatroom_manager_file_save (EmpathyChatroomManager *manager)
 			continue;
 		}
 
-		account_id = mc_account_get_unique_name (empathy_chatroom_get_account (chatroom));
+		account_id = empathy_account_get_unique_name (
+		  empathy_chatroom_get_account (chatroom));
 
 		node = xmlNewChild (root, NULL, "chatroom", NULL);
 		xmlNewTextChild (node, NULL, "name", empathy_chatroom_get_name (chatroom));
@@ -174,7 +177,7 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 {
 	EmpathyChatroomManagerPriv *priv;
 	EmpathyChatroom            *chatroom;
-	McAccount                 *account;
+	EmpathyAccount             *account;
 	xmlNodePtr                 child;
 	gchar                     *str;
 	gchar                     *name;
@@ -220,7 +223,8 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 		xmlFree (str);
 	}
 
-	account = mc_account_lookup (account_id);
+	account = empathy_account_manager_get_account (priv->account_manager,
+		account_id);
 	if (!account) {
 		g_free (name);
 		g_free (room);
@@ -233,7 +237,6 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 	add_chatroom (manager, chatroom);
 	g_signal_emit (manager, signals[CHATROOM_ADDED], 0, chatroom);
 
-	g_object_unref (account);
 	g_free (name);
 	g_free (room);
 	g_free (account_id);
@@ -408,7 +411,7 @@ empathy_chatroom_manager_constructor (GType type,
       /* Set the default file path */
       gchar *dir;
 
-      dir = g_build_filename (g_get_home_dir (), ".gnome2", PACKAGE_NAME, NULL);
+      dir = g_build_filename (g_get_user_config_dir (), PACKAGE_NAME, NULL);
       if (!g_file_test (dir, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR))
         g_mkdir_with_parents (dir, S_IRUSR | S_IWUSR | S_IXUSR);
 
@@ -520,10 +523,11 @@ chatroom_manager_remove_link (EmpathyChatroomManager *manager,
   if (empathy_chatroom_is_favorite (chatroom))
     reset_save_timeout (manager);
 
+  priv->chatrooms = g_list_delete_link (priv->chatrooms, l);
+
   g_signal_emit (manager, signals[CHATROOM_REMOVED], 0, chatroom);
   g_signal_handlers_disconnect_by_func (chatroom, chatroom_changed_cb, manager);
 
-  priv->chatrooms = g_list_delete_link (priv->chatrooms, l);
   g_object_unref (chatroom);
 }
 
@@ -556,30 +560,28 @@ empathy_chatroom_manager_remove (EmpathyChatroomManager *manager,
 
 EmpathyChatroom *
 empathy_chatroom_manager_find (EmpathyChatroomManager *manager,
-                               McAccount *account,
+                               EmpathyAccount *account,
                                const gchar *room)
 {
 	EmpathyChatroomManagerPriv *priv;
 	GList                     *l;
 
 	g_return_val_if_fail (EMPATHY_IS_CHATROOM_MANAGER (manager), NULL);
-	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
 	g_return_val_if_fail (room != NULL, NULL);
 
 	priv = GET_PRIV (manager);
 
 	for (l = priv->chatrooms; l; l = l->next) {
 		EmpathyChatroom *chatroom;
-		McAccount      *this_account;
+		EmpathyAccount *this_account;
 		const gchar    *this_room;
 
 		chatroom = l->data;
 		this_account = empathy_chatroom_get_account (chatroom);
 		this_room = empathy_chatroom_get_room (chatroom);
 
-		if (this_account && this_room &&
-		    empathy_account_equal (account, this_account) &&
-		    strcmp (this_room, room) == 0) {
+		if (this_account && this_room && account == this_account
+				&& strcmp (this_room, room) == 0) {
 			return chatroom;
 		}
 	}
@@ -589,7 +591,7 @@ empathy_chatroom_manager_find (EmpathyChatroomManager *manager,
 
 GList *
 empathy_chatroom_manager_get_chatrooms (EmpathyChatroomManager *manager,
-				       McAccount             *account)
+				       EmpathyAccount *account)
 {
 	EmpathyChatroomManagerPriv *priv;
 	GList                     *chatrooms, *l;
@@ -608,8 +610,7 @@ empathy_chatroom_manager_get_chatrooms (EmpathyChatroomManager *manager,
 
 		chatroom = l->data;
 
-		if (empathy_account_equal (account,
-					  empathy_chatroom_get_account (chatroom))) {
+		if (account == empathy_chatroom_get_account (chatroom)) {
 			chatrooms = g_list_append (chatrooms, chatroom);
 		}
 	}
@@ -619,7 +620,7 @@ empathy_chatroom_manager_get_chatrooms (EmpathyChatroomManager *manager,
 
 guint
 empathy_chatroom_manager_get_count (EmpathyChatroomManager *manager,
-				   McAccount             *account)
+				   EmpathyAccount *account)
 {
 	EmpathyChatroomManagerPriv *priv;
 	GList                     *l;
@@ -638,8 +639,7 @@ empathy_chatroom_manager_get_count (EmpathyChatroomManager *manager,
 
 		chatroom = l->data;
 
-		if (empathy_account_equal (account,
-					   empathy_chatroom_get_account (chatroom))) {
+		if (account == empathy_chatroom_get_account (chatroom)) {
 			count++;
 		}
 	}
@@ -686,7 +686,7 @@ chatroom_manager_observe_channel_cb (EmpathyDispatcher *dispatcher,
   const gchar *roomname;
   GQuark channel_type;
   TpHandleType handle_type;
-  McAccount *account;
+  EmpathyAccount *account;
   TpConnection *connection;
 
   channel_type = empathy_dispatch_operation_get_channel_type_id (operation);
@@ -704,8 +704,8 @@ chatroom_manager_observe_channel_cb (EmpathyDispatcher *dispatcher,
   chat = EMPATHY_TP_CHAT (
     empathy_dispatch_operation_get_channel_wrapper (operation));
   connection = empathy_tp_chat_get_connection (chat);
-  account = empathy_account_manager_get_account (priv->account_manager,
-      connection);
+  account = empathy_account_manager_get_account_for_connection (
+      priv->account_manager, connection);
 
   roomname = empathy_tp_chat_get_id (chat);
 
