@@ -25,16 +25,14 @@
 
 #include <glib/gi18n-lib.h>
 #include <dbus/dbus-glib.h>
-#ifdef HAVE_NM
-#include <nm-client.h>
-#endif
 
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/util.h>
-#include <libmissioncontrol/mc-enum-types.h>
 
+#include "empathy-account-manager.h"
 #include "empathy-idle.h"
 #include "empathy-utils.h"
+#include "empathy-connectivity.h"
 
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include "empathy-debug.h"
@@ -44,25 +42,23 @@
 
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyIdle)
 typedef struct {
-	MissionControl *mc;
 	DBusGProxy     *gs_proxy;
-#ifdef HAVE_NM
-	NMClient       *nm_client;
-#endif
+	EmpathyConnectivity *connectivity;
+	gulong state_change_signal_id;
 
 	TpConnectionPresenceType      state;
 	gchar          *status;
 	TpConnectionPresenceType      flash_state;
 	gboolean        auto_away;
-	gboolean        use_nm;
 
 	TpConnectionPresenceType      away_saved_state;
-	TpConnectionPresenceType      nm_saved_state;
-	gchar          *nm_saved_status;
+	TpConnectionPresenceType      saved_state;
+	gchar          *saved_status;
 
 	gboolean        is_idle;
-	gboolean        nm_connected;
 	guint           ext_away_timeout;
+
+	EmpathyAccountManager *manager;
 } EmpathyIdlePriv;
 
 typedef enum {
@@ -78,8 +74,7 @@ enum {
 	PROP_STATE,
 	PROP_STATUS,
 	PROP_FLASH_STATE,
-	PROP_AUTO_AWAY,
-	PROP_USE_NM
+	PROP_AUTO_AWAY
 };
 
 G_DEFINE_TYPE (EmpathyIdle, empathy_idle, G_TYPE_OBJECT);
@@ -87,9 +82,10 @@ G_DEFINE_TYPE (EmpathyIdle, empathy_idle, G_TYPE_OBJECT);
 static EmpathyIdle * idle_singleton = NULL;
 
 static void
-idle_presence_changed_cb (MissionControl *mc,
+idle_presence_changed_cb (EmpathyAccountManager *manager,
 			  TpConnectionPresenceType state,
 			  gchar          *status,
+			  gchar          *status_message,
 			  EmpathyIdle    *idle)
 {
 	EmpathyIdlePriv *priv;
@@ -100,14 +96,15 @@ idle_presence_changed_cb (MissionControl *mc,
 		/* Assume our presence is offline if MC reports UNSET */
 		state = TP_CONNECTION_PRESENCE_TYPE_OFFLINE;
 
-	DEBUG ("Presence changed to '%s' (%d)", status, state);
+	DEBUG ("Presence changed to '%s' (%d) \"%s\"", status, state,
+		status_message);
 
 	g_free (priv->status);
 	priv->state = state;
-	priv->status = NULL;
-	if (!EMP_STR_EMPTY (status)) {
-		priv->status = g_strdup (status);
-	}
+	if (EMP_STR_EMPTY (status_message))
+		priv->status = NULL;
+	else
+		priv->status = g_strdup (status_message);
 
 	g_object_notify (G_OBJECT (idle), "state");
 	g_object_notify (G_OBJECT (idle), "status");
@@ -172,7 +169,7 @@ idle_session_status_changed_cb (DBusGProxy    *gs_proxy,
 		is_idle ? "yes" : "no");
 
 	if (!priv->auto_away ||
-	    (priv->nm_saved_state == TP_CONNECTION_PRESENCE_TYPE_UNSET &&
+	    (priv->saved_state == TP_CONNECTION_PRESENCE_TYPE_UNSET &&
 	     (priv->state <= TP_CONNECTION_PRESENCE_TYPE_OFFLINE ||
 	      priv->state == TP_CONNECTION_PRESENCE_TYPE_HIDDEN))) {
 		/* We don't want to go auto away OR we explicitely asked to be
@@ -187,11 +184,11 @@ idle_session_status_changed_cb (DBusGProxy    *gs_proxy,
 
 		idle_ext_away_start (idle);
 
-		if (priv->nm_saved_state != TP_CONNECTION_PRESENCE_TYPE_UNSET) {
+		if (priv->saved_state != TP_CONNECTION_PRESENCE_TYPE_UNSET) {
 		    	/* We are disconnected, when coming back from away
 		    	 * we want to restore the presence before the
 		    	 * disconnection. */
-			priv->away_saved_state = priv->nm_saved_state;
+			priv->away_saved_state = priv->saved_state;
 		} else {
 			priv->away_saved_state = priv->state;
 		}
@@ -231,56 +228,37 @@ idle_session_status_changed_cb (DBusGProxy    *gs_proxy,
 	priv->is_idle = is_idle;
 }
 
-#ifdef HAVE_NM
 static void
-idle_nm_state_change_cb (NMClient         *client,
-			 const GParamSpec *pspec,
-			 EmpathyIdle      *idle)
+idle_state_change_cb (EmpathyConnectivity *connectivity,
+		      gboolean new_online,
+		      EmpathyIdle *idle)
 {
 	EmpathyIdlePriv *priv;
-	gboolean         old_nm_connected;
-	gboolean         new_nm_connected;
-	NMState          state;
 
 	priv = GET_PRIV (idle);
 
-	if (!priv->use_nm) {
-		return;
-	}
-
-	state = nm_client_get_state (priv->nm_client);
-	old_nm_connected = priv->nm_connected;
-	new_nm_connected = !(state == NM_STATE_CONNECTING ||
-			     state == NM_STATE_DISCONNECTED);
-	priv->nm_connected = TRUE; /* To be sure _set_state will work */
-
-	DEBUG ("New network state %d", state);
-
-	if (old_nm_connected && !new_nm_connected) {
-		/* We are no more connected */
+	if (!new_online) {
+		/* We are no longer connected */
 		DEBUG ("Disconnected: Save state %d (%s)",
 				priv->state, priv->status);
-		priv->nm_saved_state = priv->state;
-		g_free (priv->nm_saved_status);
-		priv->nm_saved_status = g_strdup (priv->status);
+		priv->saved_state = priv->state;
+		g_free (priv->saved_status);
+		priv->saved_status = g_strdup (priv->status);
 		empathy_idle_set_state (idle, TP_CONNECTION_PRESENCE_TYPE_OFFLINE);
 	}
-	else if (!old_nm_connected && new_nm_connected
-			&& priv->nm_saved_state != TP_CONNECTION_PRESENCE_TYPE_UNSET) {
+	else if (new_online
+			&& priv->saved_state != TP_CONNECTION_PRESENCE_TYPE_UNSET) {
 		/* We are now connected */
 		DEBUG ("Reconnected: Restore state %d (%s)",
-				priv->nm_saved_state, priv->nm_saved_status);
+				priv->saved_state, priv->saved_status);
 		empathy_idle_set_presence (idle,
-				priv->nm_saved_state,
-				priv->nm_saved_status);
-		priv->nm_saved_state = TP_CONNECTION_PRESENCE_TYPE_UNSET;
-		g_free (priv->nm_saved_status);
-		priv->nm_saved_status = NULL;
+				priv->saved_state,
+				priv->saved_status);
+		priv->saved_state = TP_CONNECTION_PRESENCE_TYPE_UNSET;
+		g_free (priv->saved_status);
+		priv->saved_status = NULL;
 	}
-
-	priv->nm_connected = new_nm_connected;
 }
-#endif
 
 static void
 idle_finalize (GObject *object)
@@ -290,17 +268,16 @@ idle_finalize (GObject *object)
 	priv = GET_PRIV (object);
 
 	g_free (priv->status);
-	g_object_unref (priv->mc);
 
 	if (priv->gs_proxy) {
 		g_object_unref (priv->gs_proxy);
 	}
 
-#ifdef HAVE_NM
-	if (priv->nm_client) {
-		g_object_unref (priv->nm_client);
-	}
-#endif
+	g_signal_handler_disconnect (priv->connectivity,
+				     priv->state_change_signal_id);
+	priv->state_change_signal_id = 0;
+
+	g_object_unref (priv->connectivity);
 
 	idle_ext_away_stop (EMPATHY_IDLE (object));
 }
@@ -350,9 +327,6 @@ idle_get_property (GObject    *object,
 	case PROP_AUTO_AWAY:
 		g_value_set_boolean (value, empathy_idle_get_auto_away (idle));
 		break;
-	case PROP_USE_NM:
-		g_value_set_boolean (value, empathy_idle_get_use_nm (idle));
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -384,9 +358,6 @@ idle_set_property (GObject      *object,
 	case PROP_AUTO_AWAY:
 		empathy_idle_set_auto_away (idle, g_value_get_boolean (value));
 		break;
-	case PROP_USE_NM:
-		empathy_idle_set_use_nm (idle, g_value_get_boolean (value));
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -435,78 +406,25 @@ empathy_idle_class_init (EmpathyIdleClass *klass)
 								FALSE,
 								G_PARAM_READWRITE));
 
-	 g_object_class_install_property (object_class,
-					  PROP_USE_NM,
-					  g_param_spec_boolean ("use-nm",
-								"Use Network Manager",
-								"Set presence according to Network Manager",
-								TRUE,
-								G_PARAM_CONSTRUCT | G_PARAM_READWRITE));
-
 	g_type_class_add_private (object_class, sizeof (EmpathyIdlePriv));
 }
 
-static TpConnectionPresenceType
-empathy_idle_get_actual_presence (EmpathyIdle *idle, GError **error)
-{
-	McPresence presence;
-	EmpathyIdlePriv *priv = GET_PRIV (idle);
-
-	presence = mission_control_get_presence_actual (priv->mc, error);
-
-	switch (presence) {
-	case MC_PRESENCE_OFFLINE:
-		return TP_CONNECTION_PRESENCE_TYPE_OFFLINE;
-	case MC_PRESENCE_AVAILABLE:
-		return TP_CONNECTION_PRESENCE_TYPE_AVAILABLE;
-	case MC_PRESENCE_AWAY:
-		return TP_CONNECTION_PRESENCE_TYPE_AWAY;
-	case MC_PRESENCE_EXTENDED_AWAY:
-		return TP_CONNECTION_PRESENCE_TYPE_EXTENDED_AWAY;
-	case MC_PRESENCE_HIDDEN:
-		return TP_CONNECTION_PRESENCE_TYPE_HIDDEN;
-	case MC_PRESENCE_DO_NOT_DISTURB:
-		return TP_CONNECTION_PRESENCE_TYPE_BUSY;
-	default:
-		return TP_CONNECTION_PRESENCE_TYPE_OFFLINE;
-	}
-}
-
 static void
 empathy_idle_init (EmpathyIdle *idle)
 {
-	GError          *error = NULL;
 	EmpathyIdlePriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (idle,
 		EMPATHY_TYPE_IDLE, EmpathyIdlePriv);
 
 	idle->priv = priv;
 	priv->is_idle = FALSE;
-	priv->mc = empathy_mission_control_dup_singleton ();
-	priv->state = empathy_idle_get_actual_presence (idle, &error);
-	if (error) {
-		DEBUG ("Error getting actual presence: %s", error->message);
 
-		/* Fallback to OFFLINE as that's what mission_control_get_presence_actual
-		does. This also ensure to always display the status icon (there is no
-		unset presence icon). */
-		priv->state = TP_CONNECTION_PRESENCE_TYPE_OFFLINE;
-		g_clear_error (&error);
-	}
-	priv->status = mission_control_get_presence_message_actual (priv->mc, &error);
-	if (error || EMP_STR_EMPTY (priv->status)) {
-		g_free (priv->status);
-		priv->status = NULL;
+	priv->manager = empathy_account_manager_dup_singleton ();
+	priv->state = empathy_account_manager_get_global_presence (priv->manager,
+		NULL, &priv->status);
 
-		if (error) {
-			DEBUG ("Error getting actual presence message: %s", error->message);
-			g_clear_error (&error);
-		}
-	}
 
-	dbus_g_proxy_connect_signal (DBUS_G_PROXY (priv->mc),
-				     "PresenceChanged",
-				     G_CALLBACK (idle_presence_changed_cb),
-				     idle, NULL);
+	g_signal_connect (priv->manager, "global-presence-changed",
+		G_CALLBACK (idle_presence_changed_cb), idle);
 
 	priv->gs_proxy = dbus_g_proxy_new_for_name (tp_get_bus (),
 						    "org.gnome.SessionManager",
@@ -522,16 +440,9 @@ empathy_idle_init (EmpathyIdle *idle)
 		DEBUG ("Failed to get gs proxy");
 	}
 
-#ifdef HAVE_NM
-	priv->nm_client = nm_client_new ();
-	if (priv->nm_client) {
-		g_signal_connect (priv->nm_client, "notify::" NM_CLIENT_STATE,
-				  G_CALLBACK (idle_nm_state_change_cb),
-				  idle);
-	} else {
-		DEBUG ("Failed to get nm proxy");
-	}
-#endif
+	priv->connectivity = empathy_connectivity_dup_singleton ();
+	priv->state_change_signal_id = g_signal_connect (priv->connectivity,
+	    "state-change", G_CALLBACK (idle_state_change_cb), idle);
 }
 
 EmpathyIdle *
@@ -614,36 +525,31 @@ empathy_idle_set_flash_state (EmpathyIdle *idle,
 
 static void
 empathy_idle_do_set_presence (EmpathyIdle *idle,
-			   TpConnectionPresenceType   state,
-			   const gchar *status)
+			   TpConnectionPresenceType status_type,
+			   const gchar *status_message)
 {
-	McPresence mc_state = MC_PRESENCE_UNSET;
 	EmpathyIdlePriv *priv = GET_PRIV (idle);
+	const gchar *statuses[NUM_TP_CONNECTION_PRESENCE_TYPES] = {
+		NULL,
+		"offline",
+		"available",
+		"away",
+		"xa",
+		"hidden",
+		"busy",
+		NULL,
+		NULL,
+	};
+	const gchar *status;
 
-	switch (state) {
-		case TP_CONNECTION_PRESENCE_TYPE_OFFLINE:
-			mc_state = MC_PRESENCE_OFFLINE;
-			break;
-		case TP_CONNECTION_PRESENCE_TYPE_AVAILABLE:
-			mc_state = MC_PRESENCE_AVAILABLE;
-			break;
-		case TP_CONNECTION_PRESENCE_TYPE_AWAY:
-			mc_state = MC_PRESENCE_AWAY;
-			break;
-		case TP_CONNECTION_PRESENCE_TYPE_EXTENDED_AWAY:
-			mc_state = MC_PRESENCE_EXTENDED_AWAY;
-			break;
-		case TP_CONNECTION_PRESENCE_TYPE_HIDDEN:
-			mc_state = MC_PRESENCE_HIDDEN;
-			break;
-		case TP_CONNECTION_PRESENCE_TYPE_BUSY:
-			mc_state = MC_PRESENCE_DO_NOT_DISTURB;
-			break;
-		default:
-			g_assert_not_reached ();
-	}
+	g_assert (status_type > 0 && status_type < NUM_TP_CONNECTION_PRESENCE_TYPES);
 
-	mission_control_set_presence (priv->mc, mc_state, status, NULL, NULL);
+	status = statuses[status_type];
+
+	g_return_if_fail (status != NULL);
+
+	empathy_account_manager_request_global_presence (priv->manager,
+		status_type, status, status_message);
 }
 
 void
@@ -664,10 +570,9 @@ empathy_idle_set_presence (EmpathyIdle *idle,
 		status = NULL;
 	}
 
-	if (!priv->nm_connected) {
-		DEBUG ("NM not connected");
+	if (!empathy_connectivity_is_online (priv->connectivity)) {
+		DEBUG ("Empathy is not online");
 
-		priv->nm_saved_state = state;
 		if (tp_strdiff (priv->status, status)) {
 			g_free (priv->status);
 			priv->status = NULL;
@@ -676,8 +581,6 @@ empathy_idle_set_presence (EmpathyIdle *idle,
 			}
 			g_object_notify (G_OBJECT (idle), "status");
 		}
-
-		return;
 	}
 
 	empathy_idle_do_set_presence (idle, state, status);
@@ -702,42 +605,3 @@ empathy_idle_set_auto_away (EmpathyIdle *idle,
 	g_object_notify (G_OBJECT (idle), "auto-away");
 }
 
-gboolean
-empathy_idle_get_use_nm (EmpathyIdle *idle)
-{
-	EmpathyIdlePriv *priv = GET_PRIV (idle);
-
-	return priv->use_nm;
-}
-
-void
-empathy_idle_set_use_nm (EmpathyIdle *idle,
-			 gboolean     use_nm)
-{
-	EmpathyIdlePriv *priv = GET_PRIV (idle);
-
-#ifdef HAVE_NM
-	if (!priv->nm_client || use_nm == priv->use_nm) {
-		return;
-	}
-#endif
-
-	priv->use_nm = use_nm;
-
-#ifdef HAVE_NM
-	if (use_nm) {
-		idle_nm_state_change_cb (priv->nm_client, NULL, idle);
-#else
-	if (0) {
-#endif
-	} else {
-		priv->nm_connected = TRUE;
-		if (priv->nm_saved_state != TP_CONNECTION_PRESENCE_TYPE_UNSET) {
-			empathy_idle_set_state (idle, priv->nm_saved_state);
-		}
-		priv->nm_saved_state = TP_CONNECTION_PRESENCE_TYPE_UNSET;
-	}
-
-	g_object_notify (G_OBJECT (idle), "use-nm");
-}
-
