@@ -26,6 +26,7 @@
 #include <telepathy-glib/channel.h>
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/util.h>
+#include <telepathy-glib/interfaces.h>
 
 #include "empathy-tp-chat.h"
 #include "empathy-tp-contact-factory.h"
@@ -1328,13 +1329,16 @@ empathy_tp_chat_set_state (EmpathyTpChat      *chat,
 	g_return_if_fail (EMPATHY_IS_TP_CHAT (chat));
 	g_return_if_fail (priv->ready);
 
-	DEBUG ("Set state: %d", state);
-	tp_cli_channel_interface_chat_state_call_set_chat_state (priv->channel, -1,
-								 state,
-								 tp_chat_async_cb,
-								 "setting chat state",
-								 NULL,
-								 G_OBJECT (chat));
+	if (tp_proxy_has_interface_by_id (priv->channel,
+					  TP_IFACE_QUARK_CHANNEL_INTERFACE_CHAT_STATE)) {
+		DEBUG ("Set state: %d", state);
+		tp_cli_channel_interface_chat_state_call_set_chat_state (priv->channel, -1,
+									 state,
+									 tp_chat_async_cb,
+									 "setting chat state",
+									 NULL,
+									 G_OBJECT (chat));
+	}
 }
 
 
