@@ -26,6 +26,8 @@
 #include <telepathy-glib/util.h>
 #include <telepathy-glib/gtypes.h>
 #include <telepathy-glib/dbus.h>
+#include <telepathy-glib/interfaces.h>
+
 #if HAVE_GEOCLUE
 #include <geoclue/geoclue-geocode.h>
 #endif
@@ -128,7 +130,7 @@ tp_contact_factory_set_aliases_cb (TpConnection *connection,
 }
 
 static void
-tp_contact_factory_set_location_cb (TpProxy *proxy,
+tp_contact_factory_set_location_cb (TpConnection *tp_conn,
 				    const GError *error,
 				    gpointer user_data,
 				    GObject *weak_object)
@@ -494,21 +496,47 @@ tp_contact_factory_geocode (EmpathyContact *contact)
 
 	address = geoclue_address_details_new ();
 
+	str = get_dup_string (location, EMPATHY_LOCATION_COUNTRY_CODE);
+	if (str != NULL) {
+		g_hash_table_insert (address,
+			g_strdup (GEOCLUE_ADDRESS_KEY_COUNTRYCODE), str);
+		DEBUG ("\t - countrycode: %s", str);
+	}
+
 	str = get_dup_string (location, EMPATHY_LOCATION_COUNTRY);
-	if (str != NULL)
-		g_hash_table_insert (address, g_strdup ("country"), str);
+	if (str != NULL) {
+		g_hash_table_insert (address,
+			g_strdup (GEOCLUE_ADDRESS_KEY_COUNTRY), str);
+		DEBUG ("\t - country: %s", str);
+	}
 
 	str = get_dup_string (location, EMPATHY_LOCATION_POSTAL_CODE);
-	if (str != NULL)
-		g_hash_table_insert (address, g_strdup ("postalcode"), str);
+	if (str != NULL) {
+		g_hash_table_insert (address,
+			g_strdup (GEOCLUE_ADDRESS_KEY_POSTALCODE), str);
+		DEBUG ("\t - postalcode: %s", str);
+	}
+
+	str = get_dup_string (location, EMPATHY_LOCATION_REGION);
+	if (str != NULL) {
+		g_hash_table_insert (address,
+			g_strdup (GEOCLUE_ADDRESS_KEY_REGION), str);
+		DEBUG ("\t - region: %s", str);
+	}
 
 	str = get_dup_string (location, EMPATHY_LOCATION_LOCALITY);
-	if (str != NULL)
-		g_hash_table_insert (address, g_strdup ("locality"), str);
+	if (str != NULL) {
+		g_hash_table_insert (address,
+			g_strdup (GEOCLUE_ADDRESS_KEY_LOCALITY), str);
+		DEBUG ("\t - locality: %s", str);
+	}
 
 	str = get_dup_string (location, EMPATHY_LOCATION_STREET);
-	if (str != NULL)
-		g_hash_table_insert (address, g_strdup ("street"), str);
+	if (str != NULL) {
+		g_hash_table_insert (address,
+			g_strdup (GEOCLUE_ADDRESS_KEY_STREET), str);
+		DEBUG ("\t - street: %s", str);
+	}
 
 	g_object_ref (contact);
 	geoclue_geocode_address_to_position_async (geocode, address,
@@ -542,7 +570,7 @@ tp_contact_factory_update_location (EmpathyTpContactFactory *tp_factory,
 }
 
 static void
-tp_contact_factory_got_locations (TpProxy                 *tp_proxy,
+tp_contact_factory_got_locations (TpConnection                 *tp_conn,
 				  GHashTable              *locations,
 				  const GError            *error,
 				  gpointer                 user_data,
@@ -598,7 +626,7 @@ tp_contact_factory_capabilities_changed_cb (TpConnection    *connection,
 }
 
 static void
-tp_contact_factory_location_updated_cb (TpProxy      *proxy,
+tp_contact_factory_location_updated_cb (TpConnection      *tp_conn,
 					guint         handle,
 					GHashTable   *location,
 					gpointer      user_data,
@@ -769,8 +797,8 @@ tp_contact_factory_add_contact (EmpathyTpContactFactory *tp_factory,
 	g_clear_error (&error);
 
 	if (tp_proxy_has_interface_by_id (TP_PROXY (priv->connection),
-		EMP_IFACE_QUARK_CONNECTION_INTERFACE_LOCATION)) {
-		emp_cli_connection_interface_location_call_get_locations (TP_PROXY (priv->connection),
+		TP_IFACE_QUARK_CONNECTION_INTERFACE_LOCATION)) {
+		tp_cli_connection_interface_location_call_get_locations (priv->connection,
 									 -1,
 									 &handles,
 									 tp_contact_factory_got_locations,
@@ -1176,7 +1204,7 @@ empathy_tp_contact_factory_set_location (EmpathyTpContactFactory *tp_factory,
 
 	DEBUG ("Setting location");
 
-	emp_cli_connection_interface_location_call_set_location (TP_PROXY (priv->connection),
+	tp_cli_connection_interface_location_call_set_location (priv->connection,
 								 -1,
 								 location,
 								 tp_contact_factory_set_location_cb,
@@ -1290,7 +1318,7 @@ tp_contact_factory_constructor (GType                  type,
 										  NULL);
 
 
-	emp_cli_connection_interface_location_connect_to_location_updated (TP_PROXY (priv->connection),
+	tp_cli_connection_interface_location_connect_to_location_updated (priv->connection,
 									   tp_contact_factory_location_updated_cb,
 									   NULL, NULL,
 									   G_OBJECT (tp_factory),
